@@ -43,6 +43,7 @@ private:
     GLuint _y_tex[2][2];
     GLuint _u_tex[2][2];
     GLuint _v_tex[2][2];
+    GLuint _mask_tex;
     int _active_tex_set;
     bool _input_is_mono;
     video_output_state _state;
@@ -51,9 +52,10 @@ private:
     float _tex_max_y;
     bool _yuv420p_supported;
     GLuint _pbo;
+    bool _have_valid_data;
 
     void bind_textures(int unitset, int index);
-    void draw_full_quad();
+    void draw_quad(float x, float y, float w, float h);
 
 protected:
     void set_mode(enum video_output::mode mode);
@@ -63,8 +65,8 @@ protected:
     void set_state(const video_output_state &_state);
     void initialize(bool have_pixel_buffer_object, bool have_texture_non_power_of_two, bool have_fragment_shader);
     void deinitialize();
-    void display(enum video_output::mode mode);
-    void display() { display(_mode); }
+    void display(enum video_output::mode mode, float x, float y, float w, float h);
+    void display() { display(_mode, -1.0f, -1.0f, 2.0f, 2.0f); }
     void reshape(int w, int h);
     void swap_tex_set();
     video_output_state &state()
@@ -92,7 +94,7 @@ protected:
     virtual int window_pos_y() = 0;
 
 public:
-    video_output_opengl() throw ();
+    video_output_opengl(bool receive_notifications = true) throw ();
     ~video_output_opengl();
 
     virtual bool supports_stereo() = 0;
